package com.gic.store.service.impl;

import com.gic.commons.util.EntityUtil;
import com.gic.store.dao.mapper.TabClerkPositionMapper;
import com.gic.store.dto.ClerkPositionDTO;
import com.gic.store.entity.TabClerkPosition;
import com.gic.store.service.ClerkPositionService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @author zhiwj
 * @Description:
 * @date 2020-07-15 17:08
 */
@Service
public class ClerkPositionServiceImpl implements ClerkPositionService {

    @Autowired
    private TabClerkPositionMapper tabClerkPositionMapper;

    @Override
    public boolean isPositionNameRepeat(Integer enterpriseId, String positionName, Integer clerkPositionId) {
        TabClerkPosition tabClerkPosition = new TabClerkPosition();
        tabClerkPosition.setEnterpriseId(enterpriseId);
        tabClerkPosition.setPositionName(positionName);
        tabClerkPosition.setClerkPositionId(clerkPositionId);
        return tabClerkPositionMapper.getSelective(tabClerkPosition) != null;
    }

    @Override
    public boolean isPositionCodeRepeat(Integer enterpriseId, String positionCode, Integer clerkPositionId) {
        TabClerkPosition tabClerkPosition = new TabClerkPosition();
        tabClerkPosition.setEnterpriseId(enterpriseId);
        tabClerkPosition.setPositionName(positionCode);
        tabClerkPosition.setClerkPositionId(clerkPositionId);
        return tabClerkPositionMapper.getSelective(tabClerkPosition) != null;
    }

    @Override
    public void save(ClerkPositionDTO clerkPositionDTO) {
        TabClerkPosition clerkPosition = EntityUtil.changeEntityByJSON(TabClerkPosition.class, clerkPositionDTO);
        clerkPosition.setCreateTime(new Date());
        clerkPosition.setStatus(1);
        tabClerkPositionMapper.insertSelective(clerkPosition);
    }

    @Override
    public void update(ClerkPositionDTO clerkPositionDTO) {
        TabClerkPosition clerkPosition = EntityUtil.changeEntityByJSON(TabClerkPosition.class, clerkPositionDTO);
        tabClerkPositionMapper.updateByPrimaryKeySelective(clerkPosition);
    }

    @Override
    public TabClerkPosition getByClerkPositionId(Integer clerkPositionId) {
        return tabClerkPositionMapper.selectByPrimaryKey(clerkPositionId);
    }

    @Override
    public Page<TabClerkPosition> listClerkPosition(String search, Integer currentPage, Integer pageSize) {
        PageHelper.startPage(currentPage, pageSize);
        return tabClerkPositionMapper.listClerkPosition(search);
    }

    @Override
    public List<TabClerkPosition> listAllClerkPosition(String search) {
        return tabClerkPositionMapper.listClerkPosition(search);
    }

    @Override
    public void deleteById(Integer clerkPositionId) {
        TabClerkPosition clerkPosition = new TabClerkPosition();
        clerkPosition.setClerkPositionId(clerkPositionId);
        clerkPosition.setStatus(0);
        tabClerkPositionMapper.updateByPrimaryKeySelective(clerkPosition);
    }
}
