package com.gic.store.service.outer.impl;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.store.dto.ClerkPositionDTO;
import com.gic.store.entity.TabClerkPosition;
import com.gic.store.service.ClerkPositionApiService;
import com.gic.store.service.ClerkPositionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service("clerkPositionApiService")
public class ClerkPositionApiServiceImpl implements ClerkPositionApiService {

    @Autowired
    private ClerkPositionService clerkPositionService;

    @Override
    public ServiceResponse<Void> save(ClerkPositionDTO clerkPositionDTO) {
        // 校验参数
        if (clerkPositionService.isPositionNameRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionName(), null)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色名称错误");
        }
        if (clerkPositionService.isPositionCodeRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionCode(), null)) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色代码错误");
        }
        // 保存实体
        clerkPositionService.save(clerkPositionDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> update(ClerkPositionDTO clerkPositionDTO) {
        if (clerkPositionService.isPositionNameRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionName(), clerkPositionDTO.getClerkPositionId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色名称错误");
        }
        if (clerkPositionService.isPositionCodeRepeat(clerkPositionDTO.getEnterpriseId(), clerkPositionDTO.getPositionCode(), clerkPositionDTO.getClerkPositionId())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "角色代码错误");
        }
        // 保存实体
        clerkPositionService.update(clerkPositionDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<ClerkPositionDTO> getByClerkPositionId(Integer clerkPositionId) {
        TabClerkPosition clerkPosition = this.clerkPositionService.getByClerkPositionId(clerkPositionId);
        ClerkPositionDTO clerkPositionDTO = EntityUtil.changeEntityByJSON(ClerkPositionDTO.class, clerkPosition);
        return EnterpriseServiceResponse.success(clerkPositionDTO);
    }

    @Override
    public ServiceResponse<Page<ClerkPositionDTO>> listClerkPosition(String search, Integer currentPage, Integer pageSize) {
        com.github.pagehelper.Page<TabClerkPosition> clerkPositionList = clerkPositionService.listClerkPosition(search, currentPage, pageSize);
        Page<ClerkPositionDTO> clerkPositionDTOPage = PageHelperUtils.changePageHelperToCurrentPage(clerkPositionList, ClerkPositionDTO.class);
        return EnterpriseServiceResponse.success(clerkPositionDTOPage);
    }

    @Override
    public ServiceResponse<List<ClerkPositionDTO>> listAllClerkPosition(String search) {
        List<TabClerkPosition> clerkPositionList = clerkPositionService.listAllClerkPosition(search);
        return EnterpriseServiceResponse.success(EntityUtil.changeEntityListByJSON(ClerkPositionDTO.class, clerkPositionList));
    }

    @Override
    public ServiceResponse<Void> setSort(Integer enterpriseId, Integer clerkPositionId, Integer seq) {
        return null;
    }

    @Override
    public ServiceResponse<Void> delete(Integer clerkPositionId) {
        TabClerkPosition clerkPosition = this.clerkPositionService.getByClerkPositionId(clerkPositionId);
        if (clerkPosition == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "数据不存在或已删除");
        }
        this.clerkPositionService.deleteById(clerkPositionId);
        return EnterpriseServiceResponse.success();
    }

}